@@ -3,8 +3,12 @@ function _aws_cdk_aws_macie_CfnAllowListProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (!visitedObjects.has(p.criteria))
+            _aws_cdk_aws_macie_CfnAllowList_CriteriaProperty(p.criteria);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -12,6 +16,10 @@ function _aws_cdk_aws_macie_CfnAllowListProps(p) {
 }
 function _aws_cdk_aws_macie_CfnAllowList(p) {
 }
+function _aws_cdk_aws_macie_CfnAllowList_CriteriaProperty(p) {
+}
+function _aws_cdk_aws_macie_CfnAllowList_S3WordsListProperty(p) {
+}
 function _aws_cdk_aws_macie_CfnCustomDataIdentifierProps(p) {
 }
 function _aws_cdk_aws_macie_CfnCustomDataIdentifier(p) {
@@ -64,4 +72,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_macie_CfnAllowListProps, _aws_cdk_aws_macie_CfnAllowList, _aws_cdk_aws_macie_CfnCustomDataIdentifierProps, _aws_cdk_aws_macie_CfnCustomDataIdentifier, _aws_cdk_aws_macie_CfnFindingsFilterProps, _aws_cdk_aws_macie_CfnFindingsFilter, _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty, _aws_cdk_aws_macie_CfnFindingsFilter_FindingsFilterListItemProperty, _aws_cdk_aws_macie_CfnSessionProps, _aws_cdk_aws_macie_CfnSession };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_macie_CfnAllowListProps, _aws_cdk_aws_macie_CfnAllowList, _aws_cdk_aws_macie_CfnAllowList_CriteriaProperty, _aws_cdk_aws_macie_CfnAllowList_S3WordsListProperty, _aws_cdk_aws_macie_CfnCustomDataIdentifierProps, _aws_cdk_aws_macie_CfnCustomDataIdentifier, _aws_cdk_aws_macie_CfnFindingsFilterProps, _aws_cdk_aws_macie_CfnFindingsFilter, _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty, _aws_cdk_aws_macie_CfnFindingsFilter_FindingsFilterListItemProperty, _aws_cdk_aws_macie_CfnSessionProps, _aws_cdk_aws_macie_CfnSession };
